@@ -12,7 +12,6 @@
 #include <QQuickRenderControl>
 #include <QWindow>
 
-#include <KAboutData>
 #include <KConfig>
 #include <KConfigGroup>
 #include <KGlobalShortcutInfo>
@@ -32,8 +31,8 @@
 
 K_PLUGIN_FACTORY_WITH_JSON(KCMKeysFactory, "kcm_keys.json", registerPlugin<KCMKeys>(); registerPlugin<KeysData>();)
 
-KCMKeys::KCMKeys(QObject *parent, const QVariantList &args)
-    : KQuickAddons::ConfigModule(parent, args)
+KCMKeys::KCMKeys(QObject *parent, const KPluginMetaData &metaData, const QVariantList &args)
+    : KQuickAddons::ConfigModule(parent, metaData, args)
 {
     constexpr char uri[] = "org.kde.private.kcms.keys";
     qmlRegisterUncreatableType<BaseModel>(uri, 2, 0, "BaseModel", "Can't create BaseModel");
@@ -43,9 +42,6 @@ KCMKeys::KCMKeys(QObject *parent, const QVariantList &args)
     qDBusRegisterMetaType<KGlobalShortcutInfo>();
     qDBusRegisterMetaType<QList<KGlobalShortcutInfo>>();
     qDBusRegisterMetaType<QList<QStringList>>();
-    KAboutData *about = new KAboutData(QStringLiteral("kcm_keys"), i18n("Shortcuts"), QStringLiteral("2.0"), QString(), KAboutLicense::GPL);
-    about->addAuthor(i18n("David Redondo"), QString(), QStringLiteral("kde@david-redondo.de"));
-    setAboutData(about);
     m_globalAccelInterface = new KGlobalAccelInterface(QStringLiteral("org.kde.kglobalaccel"), //
                                                        QStringLiteral("/kglobalaccel"),
                                                        QDBusConnection::sessionBus(),
@@ -65,6 +61,7 @@ KCMKeys::KCMKeys(QObject *parent, const QVariantList &args)
     m_filteredModel = new FilteredShortcutsModel(this);
     m_filteredModel->setSourceModel(m_shortcutsModel);
 
+    m_argument = args.isEmpty() ? QString() : args.first().toString();
     connect(m_shortcutsModel, &QAbstractItemModel::dataChanged, this, [this] {
         setNeedsSave(m_globalAccelModel->needsSave() || m_standardShortcutsModel->needsSave());
         setRepresentsDefaults(m_globalAccelModel->isDefault() && m_standardShortcutsModel->isDefault());
@@ -73,6 +70,17 @@ KCMKeys::KCMKeys(QObject *parent, const QVariantList &args)
         setNeedsSave(false);
         setRepresentsDefaults(m_globalAccelModel->isDefault() && m_standardShortcutsModel->isDefault());
     });
+    connect(m_globalAccelModel, &QAbstractItemModel::modelReset, this, [this] {
+        if (!m_argument.isEmpty()) {
+            for (int i = 0, c = m_filteredModel->rowCount(); i < c; ++i) {
+                if (m_filteredModel->data(m_filteredModel->index(i, 0), BaseModel::ComponentRole) == m_argument) {
+                    Q_EMIT showComponent(i);
+                    break;
+                }
+            }
+            m_argument.clear();
+        }
+    });
 
     connect(m_globalAccelModel, &GlobalAccelModel::errorOccured, this, &KCMKeys::setError);
 }
@@ -158,6 +166,7 @@ void KCMKeys::addApplication(QQuickItem *ctx)
         dialog->setWindowModality(Qt::WindowModal);
     }
     dialog->hideRunInTerminal();
+    dialog->setSaveNewApplications(true);
     dialog->open();
     connect(dialog, &KOpenWithDialog::finished, this, [this, dialog](int result) {
         if (result == QDialog::Accepted && dialog->service()) {
@@ -261,3 +270,4 @@ void KCMKeys::requestKeySequence(QQuickItem *context, const QModelIndex &index,
 }
 
 #include "kcm_keys.moc"
+#include "moc_kcm_keys.cpp"
